@@ -146,19 +146,20 @@ my %override = (
     },
     ssh => {
         # description is too complex to parse
-        EscapeChar => $uniline,
         ControlPersist => $uniline,
+        EscapeChar => $uniline,
         GlobalKnownHostsFile => $uniline.' default="/etc/ssh/ssh_known_hosts /etc/ssh/ssh_known_hosts2"',
         Host => $ssh_host,
         IdentityFile => $uniline_list,
+        KbdInteractiveDevices => $uniline_list,
         LocalForward => $ssh_forward,
         Match => $ssh_host,
-        StrictHostKeyChecking => 'type=leaf value_type=enum '
-           . 'choice=yes,accept-new,no,off,ask upstream_default=ask',
-        UserKnownHostsFile => "$uniline_list",
-        KbdInteractiveDevices => $uniline_list,
+        ObscureKeystrokeTiming => 'type=leaf value_type=uniline upstream_default="interval:20"',
         PreferredAuthentications => $uniline_list,
         RemoteForward => $ssh_forward,
+        StrictHostKeyChecking => 'type=leaf value_type=enum '
+        . 'choice=yes,accept-new,no,off,ask upstream_default=ask',
+        UserKnownHostsFile => "$uniline_list",
     },
     sshd => {
         AuthenticationMethods => $uniline,
@@ -168,9 +169,15 @@ my %override = (
         ForceCommand => 'type=leaf value_type=uniline upstream_default="none"',
         GSSAPIStoreCredentialsOnRekey => "$yes_no_leaf upstream_default=no",
         IgnoreUserKnownHosts => "$yes_no_leaf upstream_default=no",
+        MaxStartups => 'type=leaf value_type=uniline upstream_default=10',
+        PAMServiceName => 'type=leaf value_type=uniline level=hidden ' .
+        # this parameter shows up only when UsePAM is true
+        'warp follow:use_pam="- UsePAM" rules:"$use_pam" level=normal',
+        ForceCommand => 'type=leaf value_type=uniline upstream_default="none"',
+        PasswordAuthentication => 'type=leaf value_type=uniline upstream_default=sshd',
+        PerSourcePenalties => 'type=leaf value_type=uniline',
         Subsystem => 'type=hash index_type=string '
             . 'cargo type=leaf value_type=uniline mandatory=1 - - ',
-        MaxStartups => 'type=leaf value_type=uniline upstream_default=10',
         VersionAddendum => $uniline,
     }
 );
